@@ -6,16 +6,17 @@
 
 from splinter.meta import InheritedDocs
 
+
 class CookieManagerAPI(object):
     """
     An API that specifies how a splinter driver deals with cookies.
 
     You can add cookies using the :meth:`add <CookieManagerAPI.add>` method,
-    and remove one or all cookies using the :meth:`delete <CookieManagerAPI.delete>`
-    method.
+    and remove one or all cookies using
+    the :meth:`delete <CookieManagerAPI.delete>` method.
 
-    A CookieManager acts like a ``dict``, so you can access the value of a cookie through the []
-    operator, passing the cookie identifier:
+    A CookieManager acts like a ``dict``, so you can access the value of a
+    cookie through the [] operator, passing the cookie identifier:
 
         >>> cookie_manager.add({ 'name' : 'Tony' })
         >>> assert cookie_manager['name'] == 'Tony'
@@ -26,8 +27,8 @@ class CookieManagerAPI(object):
         """
         Adds a cookie.
 
-        The ``cookie`` parameter is a ``dict`` where each key is an identifier for the cookie
-        value (like any ``dict``).
+        The ``cookie`` parameter is a ``dict`` where each key is an identifier
+        for the cookie value (like any ``dict``).
 
         Example of use:
 
@@ -37,14 +38,16 @@ class CookieManagerAPI(object):
 
     def delete(self, *cookies):
         """
-        Deletes one or more cookies. You can pass all the cookies identifier that you want to delete.
+        Deletes one or more cookies. You can pass all the cookies identifier
+        that you want to delete.
 
         If none identifier is provided, all cookies are deleted.
 
         Examples:
 
             >>> cookie.delete() # deletes all cookies
-            >>> cookie.delete('name', 'birthday', 'favorite_color') # deletes these three cookies
+            >>> cookie.delete('name', 'birthday',
+                              'favorite_color') # deletes these three cookies
             >>> cookie.delete('name') # deletes one cookie
         """
         raise NotImplementedError
