@@ -8,7 +8,8 @@
 class InheritedDocs(type):
 
     def __new__(mcs, class_name, bases, dict):
-        items_to_patch = [(k, v) for k, v in dict.items() if not k.startswith('__') and not v.__doc__]
+        items_to_patch = [(k, v) for k, v in dict.items()
+                          if not k.startswith('__') and not v.__doc__]
         for name, obj in items_to_patch:
             doc = None
             for base in bases:
